<?php
/**
 * Theme Functions.
 */

/* Theme Setup */
if (!function_exists('modern_construction_setup')):

function modern_construction_setup() {

	$GLOBALS['content_width'] = apply_filters('modern_construction_content_width', 640);

	add_theme_support('automatic-feed-links');
	add_theme_support('post-thumbnails');
	add_theme_support('title-tag');
	add_theme_support( 'align-wide' );
	add_theme_support( 'responsive-embeds' );
	add_theme_support( 'html5', array( 'comment-list', 'search-form', 'comment-form', ) );
	add_theme_support( 'wp-block-styles' );
	add_theme_support('custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	));

	add_theme_support('custom-background', array(
		'default-color' => 'f1f1f1',
	));

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style(array('css/editor-style.css', mega_construction_font_url()));
}
endif;
add_action('after_setup_theme', 'modern_construction_setup');

add_action( 'wp_enqueue_scripts', 'modern_construction_enqueue_styles' );
function modern_construction_enqueue_styles() {
	$parent_style = 'mega-construction-basic-style'; // Style handle of parent theme.
	wp_enqueue_style( 'bootstrap-css', esc_url(get_template_directory_uri()).'/css/bootstrap.css' );
	wp_enqueue_style( $parent_style, esc_url(get_template_directory_uri()) . '/style.css' );
	wp_enqueue_style( 'modern-construction-style', get_stylesheet_uri(), array( $parent_style ) );
	if (is_singular() && comments_open() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}
}

function modern_construction_remove_parent_function() {
	remove_action( 'admin_notices', 'mega_construction_activation_notice' );
	remove_action( 'admin_menu', 'mega_construction_gettingstarted' );
}
add_action( 'init', 'modern_construction_remove_parent_function');

function my_customize_register() {     
	global $wp_customize;
	$wp_customize->remove_section( 'mega_construction_theme_color_option' );  //Modify this line as needed  
} 
add_action( 'customize_register', 'my_customize_register', 11 );

function modern_construction_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'modern-construction' ),
		'description'   => __( 'Appears on blog page sidebar', 'modern-construction' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s p-2 mb-4">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title pb-2 mb-2 pt-0">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'modern-construction' ),
		'description'   => __( 'Appears on page sidebar', 'modern-construction' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s p-2 mb-4">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title pb-2 mb-2 pt-0">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Third Column Sidebar', 'modern-construction' ),
		'description'   => __( 'Appears on page sidebar', 'modern-construction' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s p-2 mb-4">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title pb-2 mb-2 pt-0">',
		'after_title'   => '</h3>',
	) );

	$modern_construction_footer_columns = get_theme_mod('modern_construction_footer_widget', '4');
	for ($i=1; $i<=$modern_construction_footer_columns; $i++) {
		register_sidebar( array(
			'name'          => __( 'Footer ', 'modern-construction' ) . $i,
			'id'            => 'footer-' . $i,
			'description'   => '',
			'before_widget' => '<aside id="%1$s" class="widget %2$s py-4">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );
	}
}
add_action( 'widgets_init', 'modern_construction_widgets_init' );

// Customizer Section
function modern_construction_customizer ( $wp_customize ) {

	$wp_customize->add_section( 'modern_construction_service_section' , array(
    	'title'      => __( 'Our Services', 'modern-construction' ),
		'priority'   => null,
		'panel' => 'mega_construction_panel_id'
	) );

	$wp_customize->add_setting('modern_construction_service_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('modern_construction_service_title',array(
		'label'	=> __('Section Title','modern-construction'),
		'section'=> 'modern_construction_service_section',
		'setting'=> 'modern_construction_service_title',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('modern_construction_service_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('modern_construction_service_text',array(
		'label'	=> __('Add Text','modern-construction'),
		'section'=> 'modern_construction_service_section',
		'setting'=> 'modern_construction_service_text',
		'type'=> 'text'
	));	

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_pst[]= 'select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_pst[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('modern_construction_category',array(
		'default' => 'select',
		'sanitize_callback' => 'mega_construction_sanitize_choices',
	));
	$wp_customize->add_control('modern_construction_category',array(
		'type'    => 'select',
		'choices' => $cat_pst,
		'label' => __('Select Category to display Latest Post','modern-construction'),
		'section' => 'modern_construction_service_section',
	));

	$args = array('numberposts' => -1);
	$post_list = get_posts($args);
	$i = 0;
	$pst[]='Select';	
	foreach($post_list as $post){
		$pst[$post->post_title] = $post->post_title;
	}

	$wp_customize->add_setting('modern_construction_post',array(
		'sanitize_callback' => 'mega_construction_sanitize_choices',
	));
	$wp_customize->add_control('modern_construction_post',array(
		'type'    => 'select',
		'choices' => $pst,
		'label' => __('Select post','modern-construction'),
		'section' => 'modern_construction_service_section',
	));
}
add_action( 'customize_register', 'modern_construction_customizer' );